@@ -9,6 +9,7 @@ from .database import *
 from .msgc import *
 from .utils import *
 from .sendemail import *
+from .qiwei import *
 
 import libsw3 as sw3
 
@@ -27,7 +28,7 @@ def appmonitor(appname):
 
 def cpt(t):
     import json
-    print(json.dumps(t,ensure_ascii=False,skipkeys=False))
+    print(json.dumps(t,ensure_ascii=False,skipkeys=False,indent=2))
 
 def crun(cmd,errquit=True):
     p(3,"执行命令: %s",cmd)
@@ -200,9 +201,12 @@ def filemd5(filename):#获取文件的md5值
 def onlyone():  #实例仅运行一次，如果有多于1个则退出运行
     if len(sys.argv)<2:return
     jg=os.popen("ps ax").read()
-    sj=re.findall("python\s+\S*%s\s+%s" %(sys.argv[0],sys.argv[1]),jg)
-    if len(sj)>1:
-        异常退出("有多于一个的实例，退出")
+    搜索串=f"python\S*\s+\S*{sys.argv[0]}\s+{sys.argv[1]}"
+    sj=re.findall(搜索串,jg)
+    搜索串2=f"python\S*\s+\S*{sys.argv[0]}\s+{sys.argv[1]}\S+"
+    sj2=re.findall(搜索串2,jg)
+    if len(sj)-len(sj2)>1:
+        异常退出("有多于一个的实例，退出\n")
 
 class taora(c_oracle):
     def __init__(self,ta="hsta",changeable=False):
@@ -415,6 +419,7 @@ def swenv(envname,dftval):  #根据默认值自动调用swenvs或者swenvi
 
 def start(gg,scriptname):   #启动
     swn.sw3=gg.get("sw3",{})
+    onlyone()
     c=c_commandarg(gg,scriptname)
     c.main()
     swexit(0)
@@ -423,7 +428,7 @@ def swok():
     '''直接置事务正常完成'''
     swexit(0)
 
-onlyone()
+stime=time.time()
 logno=1
 swdb=c_oracle()
 swid=swenv("swid",0)
@@ -435,11 +440,12 @@ if oraconn!="":
     swdb.connect(oraconn)
 else:
     swdb=None
-stime=time.time()
 srvname=swenv("srvname","")
 srvpass=swenv("srvpass","")
 xx=c_xx()
 xxtz=c_xxtz()
+istest=(swenv("istest","")!="")
+testmail=swenv("testmail","")
 
 if __name__ == "__main__":
     start(globals(),"libsw3库")
