@@ -64,6 +64,9 @@ class c_database(object):
             self.connected=True
             self.connect()
         return object.__getattribute__(self,name)
+    def __del__(self):
+        if self.connected:
+            self.conn.close()
 
 class c_mysql(c_database):
     def importdbdriver(self):
