@@ -16,7 +16,7 @@ def 获取例外数据():
             例外[类型].append(日期)
     else:
         try:
-            url="https://swnweb.test/oapi?method=workdaydata"
+            url="https://swnweb.rt/oapi?method=workdaydata"
             context = ssl._create_unverified_context()
             headers={'Accept-Charset': 'utf-8', 'Content-Type': 'application/json'}
             req =  urllib.request.Request(url,headers=headers,method='POST')
@@ -63,6 +63,13 @@ def isworkday(rq,wtype='0'):    #判断是否工作日
     else:
         return rq in 例外[wtype]
 
+def nWorkday(rq,n):     # 指定日期rq开始第N个工作日
+    if isworkday(rq): n = n - 1
+    zxrq = rq
+    for i in range(0, n):
+        zxrq = nextday(zxrq)
+    return zxrq
+
 def 下一天(rq):    #获取下一自然日
     return (datetime.datetime.strptime(rq, "%Y%m%d") + datetime.timedelta(days=1)).strftime('%Y%m%d')
 
